"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QStandardItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qstandarditem.html

    **Detailed Description**

    Items usually contain text, icons, or checkboxes.

    Each item can have its own background brush which is set with the
    **setBackground** () function. The current background brush can be found
    with **background** (). The text label for each item can be rendered with
    its own font and brush. These are specified with the **setFont** () and
    **setForeground** () functions, and read with **font** () and **foreground**
    ().

    By default, items are enabled, editable, selectable, checkable, and can be
    used both as the source of a drag and drop operation and as a drop target.
    Each item's flags can be changed by calling **setFlags** (). Checkable items
    can be checked and unchecked with the **setCheckState** () function. The
    corresponding **checkState** () function indicates whether the item is
    currently checked.

    You can store application-specific data in an item by calling **setData**
    ().

    Each item can have a two-dimensional table of child items. This makes it
    possible to build hierarchies of items. The typical hierarchy is the tree,
    in which case the child table is a table with a single column (a list).

    The dimensions of the child table can be set with **setRowCount** () and
    **setColumnCount** (). Items can be positioned in the child table with
    **setChild** (). Get a pointer to a child item with **child** (). New rows
    and columns of children can also be inserted with **insertRow** () and
    **insertColumn** (), or appended with **appendRow** () and **appendColumn**
    (). When using the append and insert functions, the dimensions of the child
    table will grow as needed.

    An existing row of children can be removed with **removeRow** () or
    **takeRow** (); correspondingly, a column can be removed with
    **removeColumn** () or **takeColumn** ().

    An item's children can be sorted by calling **sortChildren** ().

    **Subclassing**

    When subclassing QStandardItem to provide custom items, it is possible to
    define new types for them so that they can be distinguished from the base
    class. The **type** () function should be reimplemented to return a new type
    value equal to or greater than **UserType** .

    Reimplement **data** () and **setData** () if you want to perform custom
    handling of data queries and/or control how an item's data is represented.

    Reimplement **clone** () if you want **QStandardItemModel**  to be able to
    create instances of your custom item class on demand (see
    **QStandardItemModel::setItemPrototype** ()).

    Reimplement **read** () and **write** () if you want to control how items
    are represented in their serialized form.

    Reimplement **operator<** () if you want to control the semantics of item
    comparison. **operator<** () determines the sorted order when sorting items
    with **sortChildren** () or with **QStandardItemModel::sort** ().

    **See also** **QStandardItemModel** , **Item View Convenience Classes** ,
    and **Model/View Programming** .
    """

    class ItemType(enum.Enum):
        Type: QStandardItem = ...
        UserType: QStandardItem = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#QStandardItem

        **QStandardItem::QStandardItem()**

        Constructs an item.
        """
        ...

    @typing.overload
    def __init__(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#QStandardItem-1

        **QStandardItem::QStandardItem(const QString & text )**

        Constructs an item with the given **text**.
        """
        ...

    @typing.overload
    def __init__(self, icon: QIcon, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#QStandardItem-2

        **QStandardItem::QStandardItem(const QIcon & icon , const QString & text
        )**

        Constructs an item with the given **icon** and **text**.
        """
        ...

    @typing.overload
    def __init__(self, rows: int, columns: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#QStandardItem-3

        **QStandardItem::QStandardItem(int rows , int columns = 1)**

        Constructs an item with **rows** rows and **columns** columns of child
        items.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#QStandardItem-4

        **[protected] QStandardItem::QStandardItem(const QStandardItem & other
        )**

        Constructs a copy of **other**. Note that **model** () is not copied.

        This function is useful when reimplementing **clone** ().
        """
        ...

    def clearData(self) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#clearData

        **[since 5.12] void QStandardItem::clearData()**

        Removes all the data from all roles previously set.

        This function was introduced in Qt 5.12.

        **See also** **data** () and **setData** ().
        """
        ...

    def setUserTristate(self, tristate: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setUserTristate

        **[since 5.6] void QStandardItem::setUserTristate(bool tristate )**

        Sets whether the item is tristate and controlled by the user. If
        **tristate** is true, the user can cycle through three separate states;
        otherwise, the item is checkable with two states. (Note that this also
        requires that the item is checkable; see **isCheckable** ().)

        This function was introduced in Qt 5.6.

        **See also** **isUserTristate** (), **setCheckable** (), and
        **setCheckState** ().
        """
        ...

    def isUserTristate(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isUserTristate

        **[since 5.6] bool QStandardItem::isUserTristate() const**

        Returns whether the item is tristate; that is, if it's checkable with
        three separate states and the user can cycle through all three states.

        The default value is false.

        This function was introduced in Qt 5.6.

        **See also** **setUserTristate** (), **isCheckable** (), and
        **checkState** ().
        """
        ...

    def setAutoTristate(self, tristate: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setAutoTristate

        **[since 5.6] void QStandardItem::setAutoTristate(bool tristate )**

        Determines that the item is tristate and controlled by **QTreeWidget**
        if **tristate** is `true`. This enables automatic management of the
        state of parent items in **QTreeWidget**  (checked if all children are
        checked, unchecked if all children are unchecked, or partially checked
        if only some children are checked).

        This function was introduced in Qt 5.6.

        **See also** **isAutoTristate** (), **setCheckable** (), and
        **setCheckState** ().
        """
        ...

    def isAutoTristate(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isAutoTristate

        **[since 5.6] bool QStandardItem::isAutoTristate() const**

        Returns whether the item is tristate and is controlled by
        **QTreeWidget** .

        The default value is false.

        This function was introduced in Qt 5.6.

        **See also** **setAutoTristate** (), **isCheckable** (), and
        **checkState** ().
        """
        ...

    def emitDataChanged(self) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#emitDataChanged

        **[protected] void QStandardItem::emitDataChanged()**

        Causes the model associated with this item to emit a **dataChanged** ()
        signal for this item.

        You normally only need to call this function if you have subclassed
        **QStandardItem**  and reimplemented **data** () and/or **setData** ().

        **See also** **setData** ().
        """
        ...

    def appendRows(self, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#appendRows

        **void QStandardItem::appendRows(const QList<QStandardItem *> & items
        )**

        Appends rows containing **items**. The column count will not change.

        **See also** **insertRow** ().
        """
        ...

    def appendColumn(self, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#appendColumn

        **void QStandardItem::appendColumn(const QList<QStandardItem *> & items
        )**

        Appends a column containing **items**. If necessary, the row count is
        increased to the size of **items**.

        **See also** **insertColumn** ().
        """
        ...

    @typing.overload
    def appendRow(self, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#appendRow

        **void QStandardItem::appendRow(const QList<QStandardItem *> & items )**

        Appends a row containing **items**. If necessary, the column count is
        increased to the size of **items**.

        **See also** **insertRow** ().
        """
        ...

    @typing.overload
    def appendRow(self, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#appendRow-1

        **void QStandardItem::appendRow(QStandardItem * item )**

        This is an overloaded function.

        Appends a row containing **item**.

        When building a list or a tree that has only one column, this function
        provides a convenient way to append a single new item.
        """
        ...

    def setAccessibleDescription(self, aaccessibleDescription: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setAccessibleDescription

        **void QStandardItem::setAccessibleDescription(const QString &
        accessibleDescription )**

        Sets the item's accessible description to the string specified by
        **accessibleDescription**.

        The accessible description is used by assistive technologies (i.e. for
        users who cannot use conventional means of interaction).

        **See also** **accessibleDescription** () and **setAccessibleText** ().
        """
        ...

    def setAccessibleText(self, aaccessibleText: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setAccessibleText

        **void QStandardItem::setAccessibleText(const QString & accessibleText
        )**

        Sets the item's accessible text to the string specified by
        **accessibleText**.

        The accessible text is used by assistive technologies (i.e. for users
        who cannot use conventional means of interaction).

        **See also** **accessibleText** () and **setAccessibleDescription** ().
        """
        ...

    def setCheckState(self, acheckState: QtCore.Qt.CheckState) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setCheckState

        **void QStandardItem::setCheckState(Qt::CheckState state )**

        Sets the check state of the item to be **state**.

        **See also** **checkState** () and **setCheckable** ().
        """
        ...

    def setForeground(
        self,
        abrush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setForeground

        **void QStandardItem::setForeground(const QBrush & brush )**

        Sets the brush used to display the item's foreground (e.g. text) to the
        given **brush**.

        **See also** **foreground** (), **setBackground** (), and **setFont**
        ().
        """
        ...

    def setBackground(
        self,
        abrush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setBackground

        **void QStandardItem::setBackground(const QBrush & brush )**

        Sets the item's background brush to the specified **brush**.

        **See also** **background** () and **setForeground** ().
        """
        ...

    def setTextAlignment(self, atextAlignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setTextAlignment

        **void QStandardItem::setTextAlignment(Qt::Alignment alignment )**

        Sets the text alignment for the item's text to the **alignment**
        specified.

        **See also** **textAlignment** ().
        """
        ...

    def setFont(self, afont: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setFont

        **void QStandardItem::setFont(const QFont & font )**

        Sets the font used to display the item's text to the given **font**.

        **See also** **font** (), **setText** (), and **setForeground** ().
        """
        ...

    def setSizeHint(self, asizeHint: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setSizeHint

        **void QStandardItem::setSizeHint(const QSize & size )**

        Sets the size hint for the item to be **size**. If no size hint is set,
        the item delegate will compute the size hint based on the item data.

        **See also** **sizeHint** ().
        """
        ...

    def setWhatsThis(self, awhatsThis: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setWhatsThis

        **void QStandardItem::setWhatsThis(const QString & whatsThis )**

        Sets the item's "What's This?" help to the string specified by
        **whatsThis**.

        **See also** **whatsThis** (), **setStatusTip** (), and **setToolTip**
        ().
        """
        ...

    def setStatusTip(self, astatusTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setStatusTip

        **void QStandardItem::setStatusTip(const QString & statusTip )**

        Sets the item's status tip to the string specified by **statusTip**.

        **See also** **statusTip** (), **setToolTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setToolTip(self, atoolTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setToolTip

        **void QStandardItem::setToolTip(const QString & toolTip )**

        Sets the item's tooltip to the string specified by **toolTip**.

        **See also** **toolTip** (), **setStatusTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setIcon(self, aicon: QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setIcon

        **void QStandardItem::setIcon(const QIcon & icon )**

        Sets the item's icon to the **icon** specified.

        **See also** **icon** ().
        """
        ...

    def setText(self, atext: str) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setText

        **void QStandardItem::setText(const QString & text )**

        Sets the item's text to the **text** specified.

        **See also** **text** (), **setFont** (), and **setForeground** ().
        """
        ...

    def write(self, out: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#write

        **[virtual] void QStandardItem::write(QDataStream & out ) const**

        Writes the item to stream **out**. Only the data and flags of the item
        are written, not the child items.

        **See also** **read** ().
        """
        ...

    def read(self, in_: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#read

        **[virtual] void QStandardItem::read(QDataStream & in )**

        Reads the item from stream **in**. Only the data and flags of the item
        are read, not the child items.

        **See also** **write** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#type

        **[virtual] int QStandardItem::type() const**

        Returns the type of this item. The type is used to distinguish custom
        items from the base class. When subclassing **QStandardItem** , you
        should reimplement this function and return a new value greater than or
        equal to **UserType** .

        **See also** **QStandardItem::Type** .
        """
        ...

    def clone(self) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditem.html#clone

        **[virtual] QStandardItem *QStandardItem::clone() const**

        Returns a copy of this item. The item's children are not copied.

        When subclassing **QStandardItem** , you can reimplement this function
        to provide **QStandardItemModel**  with a factory that it can use to
        create new items on demand.

        **See also** **QStandardItemModel::setItemPrototype** () and
        **operator=** ().
        """
        ...

    def sortChildren(self, column: int, order: QtCore.Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#sortChildren

        **void QStandardItem::sortChildren(int column , Qt::SortOrder order =
        Qt::AscendingOrder)**

        Sorts the children of the item using the given **order** , by the values
        in the given **column**.

        **Note:** This function is recursive, therefore it sorts the children of
        the item, its grandchildren, etc.

        **See also** **operator<** ().
        """
        ...

    def takeColumn(self, column: int) -> typing.List["QStandardItem"]:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#takeColumn

        **QList<QStandardItem *> QStandardItem::takeColumn(int column )**

        Removes **column** without deleting the column items, and returns a list
        of pointers to the removed items. For items in the column that have not
        been set, the corresponding pointers in the list will be `nullptr`.

        **See also** **removeColumn** (), **insertColumn** (), and **takeRow**
        ().
        """
        ...

    def takeRow(self, row: int) -> typing.List["QStandardItem"]:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#takeRow

        **QList<QStandardItem *> QStandardItem::takeRow(int row )**

        Removes **row** without deleting the row items, and returns a list of
        pointers to the removed items. For items in the row that have not been
        set, the corresponding pointers in the list will be `nullptr`.

        **See also** **removeRow** (), **insertRow** (), and **takeColumn** ().
        """
        ...

    def takeChild(self, row: int, column: int = ...) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditem.html#takeChild

        **QStandardItem *QStandardItem::takeChild(int row , int column = 0)**

        Removes the child item at ( **row** , **column** ) without deleting it,
        and returns a pointer to the item. If there was no child at the given
        location, then this function returns `nullptr`.

        Note that this function, unlike **takeRow** () and **takeColumn** (),
        does not affect the dimensions of the child table.

        **See also** **child** (), **takeRow** (), and **takeColumn** ().
        """
        ...

    def removeColumns(self, column: int, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#removeColumns

        **void QStandardItem::removeColumns(int column , int count )**

        Removes **count** columns at column **column**. The items that were in
        those columns are deleted.

        **See also** **removeColumn** () and **removeRows** ().
        """
        ...

    def removeRows(self, row: int, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#removeRows

        **void QStandardItem::removeRows(int row , int count )**

        Removes **count** rows at row **row**. The items that were in those rows
        are deleted.

        **See also** **removeRow** () and **removeColumn** ().
        """
        ...

    def removeColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#removeColumn

        **void QStandardItem::removeColumn(int column )**

        Removes the given **column**. The items that were in the column are
        deleted.

        **See also** **takeColumn** (), **removeColumns** (), and **removeRow**
        ().
        """
        ...

    def removeRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#removeRow

        **void QStandardItem::removeRow(int row )**

        Removes the given **row**. The items that were in the row are deleted.

        **See also** **takeRow** (), **removeRows** (), and **removeColumn** ().
        """
        ...

    def insertColumns(self, column: int, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertColumns

        **void QStandardItem::insertColumns(int column , int count )**

        Inserts **count** columns of child items at column **column**.

        **See also** **insertColumn** () and **insertRows** ().
        """
        ...

    def insertColumn(
        self, column: int, items: typing.Iterable["QStandardItem"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertColumn

        **void QStandardItem::insertColumn(int column , const
        QList<QStandardItem *> & items )**

        Inserts a column at **column** containing **items**. If necessary, the
        row count is increased to the size of **items**.

        **See also** **insertColumns** () and **insertRow** ().
        """
        ...

    @typing.overload
    def insertRows(self, row: int, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertRows

        **void QStandardItem::insertRows(int row , const QList<QStandardItem *>
        & items )**

        Inserts **items** at **row**. The column count won't be changed.

        **See also** **insertRow** () and **insertColumn** ().
        """
        ...

    @typing.overload
    def insertRows(self, row: int, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertRows-1

        **void QStandardItem::insertRows(int row , int count )**

        Inserts **count** rows of child items at row **row**.

        **See also** **insertRow** () and **insertColumns** ().
        """
        ...

    @typing.overload
    def insertRow(self, row: int, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertRow

        **void QStandardItem::insertRow(int row , const QList<QStandardItem *> &
        items )**

        Inserts a row at **row** containing **items**. If necessary, the column
        count is increased to the size of **items**.

        **See also** **insertRows** () and **insertColumn** ().
        """
        ...

    @typing.overload
    def insertRow(self, arow: int, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#insertRow-1

        **void QStandardItem::insertRow(int row , QStandardItem * item )**

        This is an overloaded function.

        Inserts a row at **row** containing **item**.

        When building a list or a tree that has only one column, this function
        provides a convenient way to insert a single new item.
        """
        ...

    @typing.overload
    def setChild(self, row: int, column: int, item: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setChild

        **void QStandardItem::setChild(int row , int column , QStandardItem *
        item )**

        Sets the child item at ( **row** , **column** ) to **item**. This item
        (the parent item) takes ownership of **item**. If necessary, the row
        count and column count are increased to fit the item.

        **Note:** Passing `nullptr` as **item** removes the item.

        **See also** **child** ().
        """
        ...

    @typing.overload
    def setChild(self, arow: int, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setChild-1

        **void QStandardItem::setChild(int row , QStandardItem * item )**

        This is an overloaded function.

        Sets the child at **row** to **item**.
        """
        ...

    def child(self, row: int, column: int = ...) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditem.html#child

        **QStandardItem *QStandardItem::child(int row , int column = 0) const**

        Returns the child item at ( **row** , **column** ) if one has been set;
        otherwise returns `nullptr`.

        **See also** **setChild** (), **takeChild** (), and **parent** ().
        """
        ...

    def hasChildren(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#hasChildren

        **bool QStandardItem::hasChildren() const**

        Returns `true` if this item has any children; otherwise returns `false`.

        **See also** **rowCount** (), **columnCount** (), and **child** ().
        """
        ...

    def setColumnCount(self, columns: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setColumnCount

        **void QStandardItem::setColumnCount(int columns )**

        Sets the number of child item columns to **columns**. If this is less
        than **columnCount** (), the data in the unwanted columns is discarded.

        **See also** **columnCount** () and **setRowCount** ().
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#columnCount

        **int QStandardItem::columnCount() const**

        Returns the number of child item columns that the item has.

        **See also** **setColumnCount** () and **rowCount** ().
        """
        ...

    def setRowCount(self, rows: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setRowCount

        **void QStandardItem::setRowCount(int rows )**

        Sets the number of child item rows to **rows**. If this is less than
        **rowCount** (), the data in the unwanted rows is discarded.

        **See also** **rowCount** () and **setColumnCount** ().
        """
        ...

    def rowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#rowCount

        **int QStandardItem::rowCount() const**

        Returns the number of child item rows that the item has.

        **See also** **setRowCount** () and **columnCount** ().
        """
        ...

    def model(self) -> QStandardItemModel:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#model

        **QStandardItemModel *QStandardItem::model() const**

        Returns the **QStandardItemModel**  that this item belongs to.

        If the item is not a child of another item that belongs to the model,
        this function returns `nullptr`.

        **See also** **index** ().
        """
        ...

    def index(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#index

        **QModelIndex QStandardItem::index() const**

        Returns the **QModelIndex**  associated with this item.

        When you need to invoke item functionality in a **QModelIndex** -based
        API (e.g. **QAbstractItemView** ), you can call this function to obtain
        an index that corresponds to the item's location in the model.

        If the item is not associated with a model, an invalid **QModelIndex**
        is returned.

        **See also** **model** () and **QStandardItemModel::itemFromIndex** ().
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#column

        **int QStandardItem::column() const**

        Returns the column where the item is located in its parent's child
        table, or -1 if the item has no parent.

        **See also** **row** () and **parent** ().
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#row

        **int QStandardItem::row() const**

        Returns the row where the item is located in its parent's child table,
        or -1 if the item has no parent.

        **See also** **column** () and **parent** ().
        """
        ...

    def parent(self) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditem.html#parent

        **QStandardItem *QStandardItem::parent() const**

        Returns the item's parent item, or `nullptr` if the item has no parent.

        **Note:** For toplevel items parent() returns `nullptr`. To receive
        toplevel item's parent use **QStandardItemModel::invisibleRootItem** ()
        instead.

        **See also** **child** () and **QStandardItemModel::invisibleRootItem**
        ().
        """
        ...

    def setDropEnabled(self, dropEnabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setDropEnabled

        **void QStandardItem::setDropEnabled(bool dropEnabled )**

        Sets whether the item is drop enabled. If **dropEnabled** is true, the
        item can be used as a drop target; otherwise, it cannot.

        Note that you also need to ensure that drops are enabled in the view;
        see **QWidget::acceptDrops** (); and that the model supports the desired
        drop actions; see **QAbstractItemModel::supportedDropActions** ().

        **See also** **isDropEnabled** (), **setDragEnabled** (), and
        **setFlags** ().
        """
        ...

    def isDropEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isDropEnabled

        **bool QStandardItem::isDropEnabled() const**

        Returns whether the item is drop enabled. When an item is drop enabled,
        it can be used as a drop target.

        The default value is true.

        **See also** **setDropEnabled** (), **isDragEnabled** (), and **flags**
        ().
        """
        ...

    def setDragEnabled(self, dragEnabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setDragEnabled

        **void QStandardItem::setDragEnabled(bool dragEnabled )**

        Sets whether the item is drag enabled. If **dragEnabled** is true, the
        item can be dragged by the user; otherwise, the user cannot drag the
        item.

        Note that you also need to ensure that item dragging is enabled in the
        view; see **QAbstractItemView::dragEnabled** .

        **See also** **isDragEnabled** (), **setDropEnabled** (), and
        **setFlags** ().
        """
        ...

    def isDragEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isDragEnabled

        **bool QStandardItem::isDragEnabled() const**

        Returns whether the item is drag enabled. An item that is drag enabled
        can be dragged by the user.

        The default value is true.

        Note that item dragging must be enabled in the view for dragging to
        work; see **QAbstractItemView::dragEnabled** .

        **See also** **setDragEnabled** (), **isDropEnabled** (), and **flags**
        ().
        """
        ...

    def setCheckable(self, checkable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setCheckable

        **void QStandardItem::setCheckable(bool checkable )**

        Sets whether the item is user-checkable. If **checkable** is true, the
        item can be checked by the user; otherwise, the user cannot check the
        item.

        The item delegate will render a checkable item with a check box next to
        the item's text.

        **See also** **isCheckable** (), **setCheckState** (),
        **setUserTristate** (), and **setAutoTristate** ().
        """
        ...

    def isCheckable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isCheckable

        **bool QStandardItem::isCheckable() const**

        Returns whether the item is user-checkable.

        The default value is false.

        **See also** **setCheckable** (), **checkState** (), **isUserTristate**
        (), and **isAutoTristate** ().
        """
        ...

    def setSelectable(self, selectable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setSelectable

        **void QStandardItem::setSelectable(bool selectable )**

        Sets whether the item is selectable. If **selectable** is true, the item
        can be selected by the user; otherwise, the user cannot select the item.

        You can control the selection behavior and mode by manipulating their
        view properties; see **QAbstractItemView::selectionMode**  and
        **QAbstractItemView::selectionBehavior** .

        **See also** **isSelectable** () and **setFlags** ().
        """
        ...

    def isSelectable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isSelectable

        **bool QStandardItem::isSelectable() const**

        Returns whether the item is selectable by the user.

        The default value is true.

        **See also** **setSelectable** () and **flags** ().
        """
        ...

    def setEditable(self, editable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setEditable

        **void QStandardItem::setEditable(bool editable )**

        Sets whether the item is editable. If **editable** is true, the item can
        be edited by the user; otherwise, the user cannot edit the item.

        How the user can edit items in a view is determined by the view's edit
        triggers; see **QAbstractItemView::editTriggers** .

        **See also** **isEditable** () and **setFlags** ().
        """
        ...

    def isEditable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isEditable

        **bool QStandardItem::isEditable() const**

        Returns whether the item can be edited by the user.

        When an item is editable (and enabled), the user can edit the item by
        invoking one of the view's edit triggers; see
        **QAbstractItemView::editTriggers** .

        The default value is true.

        **See also** **setEditable** () and **flags** ().
        """
        ...

    def setEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setEnabled

        **void QStandardItem::setEnabled(bool enabled )**

        Sets whether the item is enabled. If **enabled** is true, the item is
        enabled, meaning that the user can interact with the item; if
        **enabled** is false, the user cannot interact with the item.

        This flag takes precedence over the other item flags; e.g. if an item is
        not enabled, it cannot be selected by the user, even if the
        **Qt::ItemIsSelectable**  flag has been set.

        **See also** **isEnabled** (), **Qt::ItemIsEnabled** , and **setFlags**
        ().
        """
        ...

    def isEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#isEnabled

        **bool QStandardItem::isEnabled() const**

        Returns whether the item is enabled.

        When an item is enabled, the user can interact with it. The possible
        types of interaction are specified by the other item flags, such as
        **isEditable** () and **isSelectable** ().

        The default value is true.

        **See also** **setEnabled** () and **flags** ().
        """
        ...

    def setFlags(self, flags: QtCore.Qt.ItemFlag) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setFlags

        **void QStandardItem::setFlags(Qt::ItemFlags flags )**

        Sets the item flags for the item to **flags**.

        The item flags determine how the user can interact with the item. This
        is often used to disable an item.

        **See also** **flags** () and **setData** ().
        """
        ...

    def flags(self) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#flags

        **Qt::ItemFlags QStandardItem::flags() const**

        Returns the item flags for the item.

        The item flags determine how the user can interact with the item.

        By default, items are enabled, editable, selectable, checkable, and can
        be used both as the source of a drag and drop operation and as a drop
        target.

        **See also** **setFlags** ().
        """
        ...

    def accessibleDescription(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#accessibleDescription

        **QString QStandardItem::accessibleDescription() const**

        Returns the item's accessible description.

        The accessible description is used by assistive technologies (i.e. for
        users who cannot use conventional means of interaction).

        **See also** **setAccessibleDescription** () and **accessibleText** ().
        """
        ...

    def accessibleText(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#accessibleText

        **QString QStandardItem::accessibleText() const**

        Returns the item's accessible text.

        The accessible text is used by assistive technologies (i.e. for users
        who cannot use conventional means of interaction).

        **See also** **setAccessibleText** () and **accessibleDescription** ().
        """
        ...

    def checkState(self) -> QtCore.Qt.CheckState:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#checkState

        **Qt::CheckState QStandardItem::checkState() const**

        Returns the checked state of the item.

        **See also** **setCheckState** () and **isCheckable** ().
        """
        ...

    def foreground(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#foreground

        **QBrush QStandardItem::foreground() const**

        Returns the brush used to render the item's foreground (e.g. text).

        **See also** **setForeground** () and **background** ().
        """
        ...

    def background(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#background

        **QBrush QStandardItem::background() const**

        Returns the brush used to render the item's background.

        **See also** **foreground** () and **setBackground** ().
        """
        ...

    def textAlignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#textAlignment

        **Qt::Alignment QStandardItem::textAlignment() const**

        Returns the text alignment for the item's text.

        **See also** **setTextAlignment** ().
        """
        ...

    def font(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#font

        **QFont QStandardItem::font() const**

        Returns the font used to render the item's text.

        **See also** **setFont** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#sizeHint

        **QSize QStandardItem::sizeHint() const**

        Returns the size hint set for the item, or an invalid **QSize**  if no
        size hint has been set.

        If no size hint has been set, the item delegate will compute the size
        hint based on the item data.

        **See also** **setSizeHint** ().
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#whatsThis

        **QString QStandardItem::whatsThis() const**

        Returns the item's "What's This?" help.

        **See also** **setWhatsThis** (), **toolTip** (), and **statusTip** ().
        """
        ...

    def statusTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#statusTip

        **QString QStandardItem::statusTip() const**

        Returns the item's status tip.

        **See also** **setStatusTip** (), **toolTip** (), and **whatsThis** ().
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#toolTip

        **QString QStandardItem::toolTip() const**

        Returns the item's tooltip.

        **See also** **setToolTip** (), **statusTip** (), and **whatsThis** ().
        """
        ...

    def icon(self) -> QIcon:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#icon

        **QIcon QStandardItem::icon() const**

        Returns the item's icon.

        **See also** **setIcon** () and **iconSize** .
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#text

        **QString QStandardItem::text() const**

        Returns the item's text. This is the text that's presented to the user
        in a view.

        **See also** **setText** ().
        """
        ...

    def setData(self, value: typing.Any, role: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#setData

        **[virtual] void QStandardItem::setData(const QVariant & value , int
        role = Qt::UserRole + 1)**

        Sets the item's data for the given **role** to the specified **value**.

        If you subclass **QStandardItem**  and reimplement this function, your
        reimplementation should call **emitDataChanged** () if you do not call
        the base implementation of setData(). This will ensure that e.g. views
        using the model are notified of the changes.

        **Note:** The default implementation treats **Qt::EditRole**  and
        **Qt::DisplayRole**  as referring to the same data.

        **See also** **Qt::ItemDataRole** , **data** (), and **setFlags** ().
        """
        ...

    def data(self, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qstandarditem.html#data

        **[virtual] QVariant QStandardItem::data(int role = Qt::UserRole + 1)
        const**

        Returns the item's data for the given **role** , or an invalid
        **QVariant**  if there is no data for the role.

        **Note:** The default implementation treats **Qt::EditRole**  and
        **Qt::DisplayRole**  as referring to the same data.

        **See also** **setData** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QInputDevice(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qinputdevice.html

    **Detailed Description**

    Each **QInputEvent**  contains a QInputDevice pointer to allow accessing
    device-specific properties like type, capabilities and seat. It is the
    responsibility of the platform or generic plug-ins to discover, create and
    register an instance of this class corresponding to each available input
    device, via QWindowSystemInterface::registerInputDevice(), before generating
    any input event referring to that device.

    Applications do not need to instantiate this class, but can read the
    instances pointed to by **QInputEvent::device** () and
    **QInputDevice::devices** ().
    """

    class Capability(enum.Flag):
        None_: QInputDevice = ...
        Position: QInputDevice = ...
        Area: QInputDevice = ...
        Pressure: QInputDevice = ...
        Velocity: QInputDevice = ...
        NormalizedPosition: QInputDevice = ...
        MouseEmulation: QInputDevice = ...
        PixelScroll: QInputDevice = ...
        Scroll: QInputDevice = ...
        Hover: QInputDevice = ...
        Rotation: QInputDevice = ...
        XTilt: QInputDevice = ...
        YTilt: QInputDevice = ...
        TangentialPressure: QInputDevice = ...
        ZPosition: QInputDevice = ...
        All: QInputDevice = ...

    class DeviceType(enum.Flag):
        Unknown: QInputDevice = ...
        Mouse: QInputDevice = ...
        TouchScreen: QInputDevice = ...
        TouchPad: QInputDevice = ...
        Puck: QInputDevice = ...
        Stylus: QInputDevice = ...
        Airbrush: QInputDevice = ...
        Keyboard: QInputDevice = ...
        AllDevices: QInputDevice = ...

    @typing.overload
    def __init__(
        self,
        name: str,
        systemId: int,
        type: "QInputDevice.DeviceType",
        seatName: str = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#QInputDevice

        **QInputDevice::QInputDevice(QObject * parent = nullptr)**

        Creates a new invalid input device instance as a child of **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#QInputDevice-1

        **QInputDevice::QInputDevice(const QString & name , qint64 id ,
        QInputDevice::DeviceType type , const QString & seatName = QString(),
        QObject * parent = nullptr)**

        Creates a new input device instance. The given **name** is normally a
        manufacturer-assigned model name if available, or something else
        identifiable; **id** is a platform-specific number that will be unique
        per device (for example the xinput ID on X11); **type** identifies what
        kind of device. On window systems that are capable of handling input
        from multiple users or sets of input devices at the same time (such as
        Wayland or X11), **seatName** identifies the name of the set of devices
        that will be used together. If the device is a child or slave device
        (for example one of several mice that can take turns moving the "core
        pointer"), the master device should be given as the **parent**.

        The platform plugin creates, registers and continues to own each device
        instance; usually **parent** should be given for memory management
        purposes even if there is no master for a particular device.

        By default, **capabilities** () are `None`.
        """
        ...

    def availableVirtualGeometryChanged(self, area: QtCore.QRect) -> None:
        ...

    @staticmethod
    def primaryKeyboard(seatName: str = ...) -> "QInputDevice":
        """
        https://doc.qt.io/qt-6/qinputdevice.html#primaryKeyboard

        **[static] const QInputDevice *QInputDevice::primaryKeyboard(const
        QString & seatName = QString())**

        Returns the core or master keyboard on the given seat **seatName**.
        """
        ...

    @staticmethod
    def devices() -> typing.List["QInputDevice"]:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#devices

        **[static] QList<const QInputDevice *> QInputDevice::devices()**

        Returns a list of all registered input devices (keyboards and pointing
        devices).

        **Note:** The returned list cannot be used to add new devices. To add a
        simulated touch screen for an autotest, **QTest::createTouchDevice** ()
        can be used. Platform plugins should call
        QWindowSystemInterface::registerInputDevice() to add devices as they are
        discovered.
        """
        ...

    def availableVirtualGeometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#availableVirtualGeometry

        **QRect QInputDevice::availableVirtualGeometry() const**

        Returns the region within the **virtual desktop**  that this device can
        access.

        For example a **TouchScreen**  input device is fixed in place upon a
        single physical screen, and usually calibrated so that this area is the
        same as **QScreen::geometry** (); whereas a **Mouse**  can probably
        access all screens on the virtual desktop. A Wacom graphics tablet may
        be configured in a way that it's mapped to all screens, or only to the
        screen where the user prefers to create drawings, or to the window in
        which drawing occurs. A **Stylus**  device that is integrated with a
        touchscreen may be physically limited to that screen.

        If the returned rectangle is **null** , it means this device can access
        the entire virtual desktop.

        **Note:** Getter function for property availableVirtualGeometry.
        """
        ...

    def seatName(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#seatName

        **QString QInputDevice::seatName() const**

        Returns the seat with which the device is associated, if known;
        otherwise empty.

        Devices that are intended to be used together by one user may be
        configured to have the same seat name. That is only possible on Wayland
        and X11 platforms so far.

        **Note:** Getter function for property seatName.
        """
        ...

    def systemId(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#systemId

        **qint64 QInputDevice::systemId() const**

        Returns the platform specific system ID (for example xinput ID on the
        X11 platform).

        All platforms are expected to provide a unique system ID for each
        device.

        **Note:** Getter function for property systemId.
        """
        ...

    def hasCapability(self, cap: "QInputDevice.Capability") -> bool:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#hasCapability

        **bool QInputDevice::hasCapability(QInputDevice::Capability capability )
        const**

        Returns whether the device capabilities include the given
        **capability**.
        """
        ...

    def capabilities(self) -> "QInputDevice.Capability":
        """
        https://doc.qt.io/qt-6/qinputdevice.html#capabilities

        **QInputDevice::Capabilities QInputDevice::capabilities() const**

        Returns the device capabilities.

        **Note:** Getter function for property capabilities.
        """
        ...

    def type(self) -> "QInputDevice.DeviceType":
        """
        https://doc.qt.io/qt-6/qinputdevice.html#type

        **QInputDevice::DeviceType QInputDevice::type() const**

        Returns the device type.

        **Note:** Getter function for property type.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputdevice.html#name

        **QString QInputDevice::name() const**

        Returns the device name.

        This string may be empty. It is however useful on systems that have
        multiple input devices: it can be used to differentiate from which
        device a **QPointerEvent**  originates.

        **Note:** Getter function for property name.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPaintEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qpaintevent.html

    **Detailed Description**

    Paint events are sent to widgets that need to update themselves, for
    instance when part of a widget is exposed because a covering widget was
    moved.

    The event contains a **region** () that needs to be updated, and a **rect**
    () that is the bounding rectangle of that region. Both are provided because
    many widgets cannot make much use of **region** (), and **rect** () can be
    much faster than **region** ().boundingRect().

    **Automatic Clipping**

    Painting is clipped to **region** () during the processing of a paint event.
    This clipping is performed by Qt's paint system and is independent of any
    clipping that may be applied to a **QPainter**  used to draw on the paint
    device.

    As a result, the value returned by **QPainter::clipRegion** () on a newly-
    constructed **QPainter**  will not reflect the clip region that is used by
    the paint system.

    **See also** **QPainter** , **QWidget::update** (), **QWidget::repaint** (),
    and **QWidget::paintEvent** ().
    """

    @typing.overload
    def __init__(self, paintRegion: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qpaintevent.html#QPaintEvent-2

        **QPaintEvent::QPaintEvent(const QRegion & paintRegion )**

        Constructs a paint event object with the region that needs to be
        updated. The region is specified by **paintRegion**.
        """
        ...

    @typing.overload
    def __init__(self, paintRect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qpaintevent.html#QPaintEvent-3

        **QPaintEvent::QPaintEvent(const QRect & paintRect )**

        Constructs a paint event object with the rectangle that needs to be
        updated. The region is specified by **paintRect**.
        """
        ...

    def clone(self) -> "QPaintEvent":
        ...

    def region(self) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qpaintevent.html#region

        **const QRegion &QPaintEvent::region() const**

        Returns the region that needs to be updated.

        **See also** **rect** () and **QPainter::setClipRegion** ().
        """
        ...

    def rect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpaintevent.html#rect

        **const QRect &QPaintEvent::rect() const**

        Returns the rectangle that needs to be updated.

        **See also** **region** () and **QPainter::setClipRect** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QPluginLoader(QObject):
    """
    https://doc.qt.io/qt-6/qpluginloader.html

    **Detailed Description**

    QPluginLoader provides access to a **Qt plugin** . A Qt plugin is stored in
    a shared library (a DLL) and offers these benefits over shared libraries
    accessed using **QLibrary** :

    * QPluginLoader checks that a plugin is linked against the same version of
    Qt as the application.
      * QPluginLoader provides direct access to a root
    component object (**instance** ()), instead of forcing you to resolve a C
    function manually.

    An instance of a QPluginLoader object operates on a single shared library
    file, which we call a plugin. It provides access to the functionality in the
    plugin in a platform-independent way. To specify which plugin to load,
    either pass a file name in the constructor or set it with **setFileName**
    ().

    The most important functions are **load** () to dynamically load the plugin
    file, **isLoaded** () to check whether loading was successful, and
    **instance** () to access the root component in the plugin. The **instance**
    () function implicitly tries to load the plugin if it has not been loaded
    yet. Multiple instances of QPluginLoader can be used to access the same
    physical plugin.

    Once loaded, plugins remain in memory until all instances of QPluginLoader
    has been unloaded, or until the application terminates. You can attempt to
    unload a plugin using **unload** (), but if other instances of QPluginLoader
    are using the same library, the call will fail, and unloading will only
    happen when every instance has called **unload** (). Right before the
    unloading happens, the root component will also be deleted.

    See **How to Create Qt Plugins**  for more information about how to make
    your application extensible through plugins.

    Note that the QPluginLoader cannot be used if your application is statically
    linked against Qt. In this case, you will also have to link to plugins
    statically. You can use **QLibrary**  if you need to load dynamic libraries
    in a statically linked application.

    **See also** **QLibrary**  and **Plug & Paint Example** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#QPluginLoader

        **QPluginLoader::QPluginLoader(QObject * parent = nullptr)**

        Constructs a plugin loader with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#QPluginLoader-1

        **QPluginLoader::QPluginLoader(const QString & fileName , QObject *
        parent = nullptr)**

        Constructs a plugin loader with the given **parent** that will load the
        plugin specified by **fileName**.

        To be loadable, the file's suffix must be a valid suffix for a loadable
        library in accordance with the platform, e.g. `.so` on Unix, - `.dylib`
        on macOS and iOS, and `.dll` on Windows. The suffix can be verified with
        **QLibrary::isLibrary** ().

        **See also** **setFileName** ().
        """
        ...

    def loadHints(self) -> QLibrary.LoadHint:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#loadHints-prop

        **loadHints : QLibrary::LoadHints**

        Give the **load** () function some hints on how it should behave.

        You can give hints on how the symbols in the plugin are resolved. By
        default since Qt 5.7, **QLibrary::PreventUnloadHint**  is set.

        See the documentation of **QLibrary::loadHints**  for a complete
        description of how this property works.

        **Access functions:**

        QLibrary::LoadHints **loadHints** () const
        void **setLoadHints**
        (QLibrary::LoadHints **loadHints** )

        **See also** **QLibrary::loadHints** .

        **Member Function Documentation**
        """
        ...

    def setLoadHints(self, loadHints: QLibrary.LoadHint) -> None:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#loadHints-prop

        **loadHints : QLibrary::LoadHints**

        Give the **load** () function some hints on how it should behave.

        You can give hints on how the symbols in the plugin are resolved. By
        default since Qt 5.7, **QLibrary::PreventUnloadHint**  is set.

        See the documentation of **QLibrary::loadHints**  for a complete
        description of how this property works.

        **Access functions:**

        QLibrary::LoadHints **loadHints** () const
        void **setLoadHints**
        (QLibrary::LoadHints **loadHints** )

        **See also** **QLibrary::loadHints** .

        **Member Function Documentation**
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#errorString

        **QString QPluginLoader::errorString() const**

        Returns a text string with the description of the last error that
        occurred.
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#fileName-prop

        **fileName : QString**

        This property holds the file name of the plugin

        We recommend omitting the file's suffix in the file name, since
        **QPluginLoader**  will automatically look for the file with the
        appropriate suffix (see **QLibrary::isLibrary** ()).

        When loading the plugin, **QPluginLoader**  searches in all plugin
        locations specified by **QCoreApplication::libraryPaths** (), unless the
        file name has an absolute path. After loading the plugin successfully,
        fileName() returns the fully-qualified file name of the plugin,
        including the full path to the plugin if one was given in the
        constructor or passed to setFileName().

        If the file name does not exist, it will not be set. This property will
        then contain an empty string.

        By default, this property contains an empty string.

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )

        **See also** **load** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#fileName-prop

        **fileName : QString**

        This property holds the file name of the plugin

        We recommend omitting the file's suffix in the file name, since
        **QPluginLoader**  will automatically look for the file with the
        appropriate suffix (see **QLibrary::isLibrary** ()).

        When loading the plugin, **QPluginLoader**  searches in all plugin
        locations specified by **QCoreApplication::libraryPaths** (), unless the
        file name has an absolute path. After loading the plugin successfully,
        fileName() returns the fully-qualified file name of the plugin,
        including the full path to the plugin if one was given in the
        constructor or passed to setFileName().

        If the file name does not exist, it will not be set. This property will
        then contain an empty string.

        By default, this property contains an empty string.

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )

        **See also** **load** ().
        """
        ...

    def isLoaded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#isLoaded

        **bool QPluginLoader::isLoaded() const**

        Returns `true` if the plugin is loaded; otherwise returns `false`.

        **See also** **load** ().
        """
        ...

    def unload(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#unload

        **bool QPluginLoader::unload()**

        Unloads the plugin and returns `true` if the plugin could be unloaded;
        otherwise returns `false`.

        This happens automatically on application termination, so you shouldn't
        normally need to call this function.

        If other instances of **QPluginLoader**  are using the same plugin, the
        call will fail, and unloading will only happen when every instance has
        called unload().

        Don't try to delete the root component. Instead rely on that unload()
        will automatically delete it when needed.

        **See also** **instance** () and **load** ().
        """
        ...

    def load(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#load

        **bool QPluginLoader::load()**

        Loads the plugin and returns `true` if the plugin was loaded
        successfully; otherwise returns `false`. Since **instance** () always
        calls this function before resolving any symbols it is not necessary to
        call it explicitly. In some situations you might want the plugin loaded
        in advance, in which case you would use this function.

        **See also** **unload** ().
        """
        ...

    @staticmethod
    def staticInstances() -> typing.List[QObject]:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#staticInstances

        **[static] QObjectList QPluginLoader::staticInstances()**

        Returns a list of static plugin instances (root components) held by the
        plugin loader.

        **See also** **staticPlugins** ().
        """
        ...

    def instance(self) -> QObject:
        """
        https://doc.qt.io/qt-6/qpluginloader.html#instance

        **QObject *QPluginLoader::instance()**

        Returns the root component object of the plugin. The plugin is loaded if
        necessary. The function returns `nullptr` if the plugin could not be
        loaded or if the root component object could not be instantiated.

        If the root component object was destroyed, calling this function
        creates a new instance.

        The root component, returned by this function, is not deleted when the
        **QPluginLoader**  is destroyed. If you want to ensure that the root
        component is deleted, you should call **unload** () as soon you don't
        need to access the core component anymore. When the library is finally
        unloaded, the root component will automatically be deleted.

        The component object is a **QObject** . Use **qobject_cast** () to
        access interfaces you are interested in.

        **See also** **load** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QPointF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpointf.html

    **Detailed Description**

    A point is specified by a x coordinate and an y coordinate which can be
    accessed using the **x** () and **y** () functions. The coordinates of the
    point are specified using finite floating point numbers for accuracy. The
    **isNull** () function returns `true` if both x and y are set to 0.0. The
    coordinates can be set (or altered) using the **setX** () and **setY** ()
    functions, or alternatively the **rx** () and **ry** () functions which
    return references to the coordinates (allowing direct manipulation).

    Given a point **p** , the following statements are all equivalent:

    **QPointF**  p;

        p.setX(p.x() + 1.0);
        p += **QPointF** (1.0,
    0.0);
        p.rx()++;

    A QPointF object can also be used as a vector: Addition and subtraction are
    defined as for vectors (each component is added separately). A QPointF
    object can also be divided or multiplied by an `int` or a `qreal`.

    In addition, the QPointF class provides a constructor converting a
    **QPoint**  object into a QPointF object, and a corresponding **toPoint** ()
    function which returns a **QPoint**  copy of **this** point. Finally,
    QPointF objects can be streamed as well as compared.

    **See also** **QPoint**  and **QPolygonF** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#QPointF

        **QPointF::QPointF()**

        Constructs a null point, i.e. with coordinates (0.0, 0.0)

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, xpos: float, ypos: float) -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#QPointF-1

        **QPointF::QPointF(const QPoint & point )**

        Constructs a copy of the given **point**.

        **See also** **toPoint** ().
        """
        ...

    @typing.overload
    def __init__(self, p: QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#QPointF-2

        **QPointF::QPointF(qreal xpos , qreal ypos )**

        Constructs a point with the given coordinates ( **xpos** , **ypos** ).

        **See also** **setX** () and **setY** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPointF") -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#QPointF

        **QPointF::QPointF()**

        Constructs a null point, i.e. with coordinates (0.0, 0.0)

        **See also** **isNull** ().
        """
        ...

    def __pos__(self) -> "QPointF":
        ...

    def __neg__(self) -> "QPointF":
        ...

    def transposed(self) -> "QPointF":
        """
        https://doc.qt.io/qt-6/qpointf.html#transposed

        **[since 5.14] QPointF QPointF::transposed() const**

        Returns a point with x and y coordinates exchanged:

        **QPointF** {1.0, 2.0}.transposed() // {2.0, 1.0}

        This function was introduced in Qt 5.14.

        **See also** **x** (), **y** (), **setX** (), and **setY** ().
        """
        ...

    @staticmethod
    def dotProduct(p1: "QPointF", p2: "QPointF") -> float:
        """
        https://doc.qt.io/qt-6/qpointf.html#dotProduct

        **[static, since 5.1] qreal QPointF::dotProduct(const QPointF & p1 ,
        const QPointF & p2 )**

        **QPointF**  p( 3.1, 7.1);
            **QPointF**  q(-1.0, 4.1);
            int
        lengthSquared = **QPointF** ::dotProduct(p, q);   // lengthSquared
        becomes 26.01

        Returns the dot product of **p1** and **p2**.

        This function was introduced in Qt 5.1.
        """
        ...

    def manhattanLength(self) -> float:
        """
        https://doc.qt.io/qt-6/qpointf.html#manhattanLength

        **qreal QPointF::manhattanLength() const**

        Returns the sum of the absolute values of **x** () and **y** (),
        traditionally known as the "Manhattan length" of the vector from the
        origin to the point.

        **See also** **QPoint::manhattanLength** ().
        """
        ...

    def toPoint(self) -> QPoint:
        """
        https://doc.qt.io/qt-6/qpointf.html#toPoint

        **QPoint QPointF::toPoint() const**

        Rounds the coordinates of this point to the nearest integer, and returns
        a **QPoint**  object with the rounded coordinates.

        **See also** **QPointF** ().
        """
        ...

    def setY(self, ypos: float) -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#setY

        **void QPointF::setY(qreal y )**

        Sets the y coordinate of this point to the given finite **y**
        coordinate.

        **See also** **y** () and **setX** ().
        """
        ...

    def setX(self, xpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qpointf.html#setX

        **void QPointF::setX(qreal x )**

        Sets the x coordinate of this point to the given finite **x**
        coordinate.

        **See also** **x** () and **setY** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qpointf.html#y

        **qreal QPointF::y() const**

        Returns the y coordinate of this point.

        **See also** **setY** () and **ry** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qpointf.html#x

        **qreal QPointF::x() const**

        Returns the x coordinate of this point.

        **See also** **setX** () and **rx** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpointf.html#isNull

        **bool QPointF::isNull() const**

        Returns `true` if both the x and y coordinates are set to 0.0 (ignoring
        the sign); otherwise returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsGridLayout(QGraphicsLayout):
    """
    https://doc.qt.io/qt-6/qgraphicsgridlayout.html

    **Detailed Description**

    The most common way to use QGraphicsGridLayout is to construct an object on
    the heap with no parent, add widgets and layouts by calling **addItem** (),
    and finally assign the layout to a widget by calling
    **QGraphicsWidget::setLayout** (). QGraphicsGridLayout automatically
    computes the dimensions of the grid as you add items.

    **QGraphicsScene**  scene;
        **QGraphicsWidget**  *textEdit =
    scene.addWidget(new **QTextEdit** );
        **QGraphicsWidget**  *pushButton =
    scene.addWidget(new **QPushButton** );

        **QGraphicsGridLayout**
    *layout = new **QGraphicsGridLayout** ;
        layout->addItem(textEdit, 0, 0);
    layout->addItem(pushButton, 0, 1);

        **QGraphicsWidget**  *form = new
    **QGraphicsWidget** ;
        form->setLayout(layout);
        scene.addItem(form);

    The layout takes ownership of the items. In some cases when the layout item
    also inherits from **QGraphicsItem**  (such as **QGraphicsWidget** ) there
    will be a ambiguity in ownership because the layout item belongs to two
    ownership hierarchies. See the documentation of
    **QGraphicsLayoutItem::setOwnedByLayout** () how to handle this. You can
    access each item in the layout by calling **count** () and **itemAt** ().
    Calling **removeAt** () will remove an item from the layout, without
    destroying it.

    **Size Hints and Size Policies in QGraphicsGridLayout**

    QGraphicsGridLayout respects each item's size hints and size policies, and
    when a cell in the grid has more space than the items can fill, each item is
    arranged according to the layout's alignment for that item. You can set an
    alignment for each item by calling **setAlignment** (), and check the
    alignment for any item by calling **alignment** (). You can also set the
    alignment for an entire row or column by calling **setRowAlignment** () and
    **setColumnAlignment** () respectively. By default, items are aligned to the
    top left.

    **See also** **QGraphicsLinearLayout**  and **QGraphicsWidget** .
    """

    def __init__(self, parent: typing.Optional[QGraphicsLayoutItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#QGraphicsGridLayout

        **QGraphicsGridLayout::QGraphicsGridLayout(QGraphicsLayoutItem * parent
        = nullptr)**

        Constructs a QGraphicsGridLayout instance. **parent** is passed to
        **QGraphicsLayout** 's constructor.
        """
        ...

    def removeItem(self, item: QGraphicsLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#removeItem

        **void QGraphicsGridLayout::removeItem(QGraphicsLayoutItem * item )**

        Removes the layout item **item** without destroying it. Ownership of the
        item is transferred to the caller.

        **See also** **addItem** ().
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#sizeHint

        **[override virtual] QSizeF QGraphicsGridLayout::sizeHint(Qt::SizeHint
        which , const QSizeF & constraint = QSizeF()) const**

        Reimplements: **QGraphicsLayoutItem::sizeHint(Qt::SizeHint which, const
        QSizeF &constraint) const** .
        """
        ...

    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setGeometry

        **[override virtual] void QGraphicsGridLayout::setGeometry(const QRectF
        & rect )**

        Reimplements: **QGraphicsLayoutItem::setGeometry** (const QRectF &rect).

        Sets the bounding geometry of the grid layout to **rect**.
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#invalidate

        **[override virtual] void QGraphicsGridLayout::invalidate()**

        Reimplements: **QGraphicsLayout::invalidate** ().
        """
        ...

    def removeAt(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#removeAt

        **[override virtual] void QGraphicsGridLayout::removeAt(int index )**

        Reimplements: **QGraphicsLayout::removeAt** (int index).

        Removes the layout item at **index** without destroying it. Ownership of
        the item is transferred to the caller.

        **See also** **addItem** ().
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#count

        **[override virtual] int QGraphicsGridLayout::count() const**

        Reimplements: **QGraphicsLayout::count() const** .

        Returns the number of layout items in this grid layout.
        """
        ...

    @typing.overload
    def itemAt(self, row: int, column: int) -> QGraphicsLayoutItem:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#itemAt

        **QGraphicsLayoutItem *QGraphicsGridLayout::itemAt(int row , int column
        ) const**

        Returns a pointer to the layout item at ( **row** , **column** ).
        """
        ...

    @typing.overload
    def itemAt(self, index: int) -> QGraphicsLayoutItem:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#itemAt-1

        **[override virtual] QGraphicsLayoutItem
        *QGraphicsGridLayout::itemAt(int index ) const**

        Reimplements: **QGraphicsLayout::itemAt(int i) const** .

        Returns the layout item at **index** , or `nullptr` if there is no
        layout item at this index.
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnCount

        **int QGraphicsGridLayout::columnCount() const**

        Returns the number of columns in the grid layout. This is always one
        more than the index of the last column that is occupied by a layout item
        (empty columns are counted except for those at the end).
        """
        ...

    def rowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowCount

        **int QGraphicsGridLayout::rowCount() const**

        Returns the number of rows in the grid layout. This is always one more
        than the index of the last row that is occupied by a layout item (empty
        rows are counted except for those at the end).
        """
        ...

    def alignment(self, item: QGraphicsLayoutItem) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#alignment

        **Qt::Alignment QGraphicsGridLayout::alignment(QGraphicsLayoutItem *
        item ) const**

        Returns the alignment for **item**.

        **See also** **setAlignment** ().
        """
        ...

    def setAlignment(
        self, item: QGraphicsLayoutItem, alignment: QtCore.Qt.AlignmentFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setAlignment

        **void QGraphicsGridLayout::setAlignment(QGraphicsLayoutItem * item ,
        Qt::Alignment alignment )**

        Sets the alignment for **item** to **alignment**.

        **See also** **alignment** ().
        """
        ...

    def columnAlignment(self, column: int) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnAlignment

        **Qt::Alignment QGraphicsGridLayout::columnAlignment(int column )
        const**

        Returns the alignment for **column**.

        **See also** **setColumnAlignment** ().
        """
        ...

    def setColumnAlignment(
        self, column: int, alignment: QtCore.Qt.AlignmentFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnAlignment

        **void QGraphicsGridLayout::setColumnAlignment(int column ,
        Qt::Alignment alignment )**

        Sets the alignment for **column** to **alignment**.

        **See also** **columnAlignment** ().
        """
        ...

    def rowAlignment(self, row: int) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowAlignment

        **Qt::Alignment QGraphicsGridLayout::rowAlignment(int row ) const**

        Returns the alignment of **row**.

        **See also** **setRowAlignment** ().
        """
        ...

    def setRowAlignment(self, row: int, alignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowAlignment

        **void QGraphicsGridLayout::setRowAlignment(int row , Qt::Alignment
        alignment )**

        Sets the alignment of **row** to **alignment**.

        **See also** **rowAlignment** ().
        """
        ...

    def setColumnFixedWidth(self, column: int, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnFixedWidth

        **void QGraphicsGridLayout::setColumnFixedWidth(int column , qreal width
        )**

        Sets the fixed width of **column** to **width**.
        """
        ...

    def columnMaximumWidth(self, column: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnMaximumWidth

        **qreal QGraphicsGridLayout::columnMaximumWidth(int column ) const**

        Returns the maximum width for **column**.

        **See also** **setColumnMaximumWidth** ().
        """
        ...

    def setColumnMaximumWidth(self, column: int, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnMaximumWidth

        **void QGraphicsGridLayout::setColumnMaximumWidth(int column , qreal
        width )**

        Sets the maximum width of **column** to **width**.

        **See also** **columnMaximumWidth** ().
        """
        ...

    def columnPreferredWidth(self, column: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnPreferredWidth

        **qreal QGraphicsGridLayout::columnPreferredWidth(int column ) const**

        Returns the preferred width for **column**.

        **See also** **setColumnPreferredWidth** ().
        """
        ...

    def setColumnPreferredWidth(self, column: int, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnPreferredWidth

        **void QGraphicsGridLayout::setColumnPreferredWidth(int column , qreal
        width )**

        Sets the preferred width for **column** to **width**.

        **See also** **columnPreferredWidth** ().
        """
        ...

    def columnMinimumWidth(self, column: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnMinimumWidth

        **qreal QGraphicsGridLayout::columnMinimumWidth(int column ) const**

        Returns the minimum width for **column**.

        **See also** **setColumnMinimumWidth** ().
        """
        ...

    def setColumnMinimumWidth(self, column: int, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnMinimumWidth

        **void QGraphicsGridLayout::setColumnMinimumWidth(int column , qreal
        width )**

        Sets the minimum width for **column** to **width**.

        **See also** **columnMinimumWidth** ().
        """
        ...

    def setRowFixedHeight(self, row: int, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowFixedHeight

        **void QGraphicsGridLayout::setRowFixedHeight(int row , qreal height )**

        Sets the fixed height for row, **row** , to **height**.
        """
        ...

    def rowMaximumHeight(self, row: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowMaximumHeight

        **qreal QGraphicsGridLayout::rowMaximumHeight(int row ) const**

        Returns the maximum height for row, **row**.

        **See also** **setRowMaximumHeight** ().
        """
        ...

    def setRowMaximumHeight(self, row: int, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowMaximumHeight

        **void QGraphicsGridLayout::setRowMaximumHeight(int row , qreal height
        )**

        Sets the maximum height for row, **row** , to **height**.

        **See also** **rowMaximumHeight** ().
        """
        ...

    def rowPreferredHeight(self, row: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowPreferredHeight

        **qreal QGraphicsGridLayout::rowPreferredHeight(int row ) const**

        Returns the preferred height for row, **row**.

        **See also** **setRowPreferredHeight** ().
        """
        ...

    def setRowPreferredHeight(self, row: int, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowPreferredHeight

        **void QGraphicsGridLayout::setRowPreferredHeight(int row , qreal height
        )**

        Sets the preferred height for row, **row** , to **height**.

        **See also** **rowPreferredHeight** ().
        """
        ...

    def rowMinimumHeight(self, row: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowMinimumHeight

        **qreal QGraphicsGridLayout::rowMinimumHeight(int row ) const**

        Returns the minimum height for row, **row**.

        **See also** **setRowMinimumHeight** ().
        """
        ...

    def setRowMinimumHeight(self, row: int, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowMinimumHeight

        **void QGraphicsGridLayout::setRowMinimumHeight(int row , qreal height
        )**

        Sets the minimum height for row, **row** , to **height**.

        **See also** **rowMinimumHeight** ().
        """
        ...

    def columnStretchFactor(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnStretchFactor

        **int QGraphicsGridLayout::columnStretchFactor(int column ) const**

        Returns the stretch factor for **column**.

        **See also** **setColumnStretchFactor** ().
        """
        ...

    def setColumnStretchFactor(self, column: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnStretchFactor

        **void QGraphicsGridLayout::setColumnStretchFactor(int column , int
        stretch )**

        Sets the stretch factor for **column** to **stretch**.

        **See also** **columnStretchFactor** ().
        """
        ...

    def rowStretchFactor(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowStretchFactor

        **int QGraphicsGridLayout::rowStretchFactor(int row ) const**

        Returns the stretch factor for **row**.

        **See also** **setRowStretchFactor** ().
        """
        ...

    def setRowStretchFactor(self, row: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowStretchFactor

        **void QGraphicsGridLayout::setRowStretchFactor(int row , int stretch
        )**

        Sets the stretch factor for **row** to **stretch**.

        **See also** **rowStretchFactor** ().
        """
        ...

    def columnSpacing(self, column: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#columnSpacing

        **qreal QGraphicsGridLayout::columnSpacing(int column ) const**

        Returns the column spacing for **column**.

        **See also** **setColumnSpacing** ().
        """
        ...

    def setColumnSpacing(self, column: int, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setColumnSpacing

        **void QGraphicsGridLayout::setColumnSpacing(int column , qreal spacing
        )**

        Sets the spacing for **column** to **spacing**.

        **See also** **columnSpacing** ().
        """
        ...

    def rowSpacing(self, row: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#rowSpacing

        **qreal QGraphicsGridLayout::rowSpacing(int row ) const**

        Returns the row spacing for **row**.

        **See also** **setRowSpacing** ().
        """
        ...

    def setRowSpacing(self, row: int, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setRowSpacing

        **void QGraphicsGridLayout::setRowSpacing(int row , qreal spacing )**

        Sets the spacing for **row** to **spacing**.

        **See also** **rowSpacing** ().
        """
        ...

    def setSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setSpacing

        **void QGraphicsGridLayout::setSpacing(qreal spacing )**

        Sets the grid layout's default spacing, both vertical and horizontal, to
        **spacing**.

        **See also** **rowSpacing** () and **columnSpacing** ().
        """
        ...

    def verticalSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#verticalSpacing

        **qreal QGraphicsGridLayout::verticalSpacing() const**

        Returns the default vertical spacing for the grid layout.

        **See also** **setVerticalSpacing** ().
        """
        ...

    def setVerticalSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setVerticalSpacing

        **void QGraphicsGridLayout::setVerticalSpacing(qreal spacing )**

        Sets the default vertical spacing for the grid layout to **spacing**.

        **See also** **verticalSpacing** ().
        """
        ...

    def horizontalSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#horizontalSpacing

        **qreal QGraphicsGridLayout::horizontalSpacing() const**

        Returns the default horizontal spacing for the grid layout.

        **See also** **setHorizontalSpacing** ().
        """
        ...

    def setHorizontalSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#setHorizontalSpacing

        **void QGraphicsGridLayout::setHorizontalSpacing(qreal spacing )**

        Sets the default horizontal spacing for the grid layout to **spacing**.

        **See also** **horizontalSpacing** ().
        """
        ...

    @typing.overload
    def addItem(
        self,
        item: QGraphicsLayoutItem,
        row: int,
        column: int,
        rowSpan: int,
        columnSpan: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#addItem

        **void QGraphicsGridLayout::addItem(QGraphicsLayoutItem * item , int row
        , int column , int rowSpan , int columnSpan , Qt::Alignment alignment =
        Qt::Alignment())**

        Adds **item** to the grid on **row** and **column**. You can specify a
        **rowSpan** and **columnSpan** and an optional **alignment**.
        """
        ...

    @typing.overload
    def addItem(
        self,
        item: QGraphicsLayoutItem,
        row: int,
        column: int,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsgridlayout.html#addItem-1

        **void QGraphicsGridLayout::addItem(QGraphicsLayoutItem * item , int row
        , int column , Qt::Alignment alignment = Qt::Alignment())**

        Adds **item** to the grid on **row** and **column**. You can specify an
        optional **alignment** for **item**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QMagnetometer(QSensor):
    """
    https://doc.qt.io/qt-6/qmagnetometer.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QMagnetometerReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QMagnetometerReading** .

    **See also** **QMagnetometerReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#QMagnetometer

        **QMagnetometer::QMagnetometer(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def setReturnGeoValues(self, returnGeoValues: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#returnGeoValues-prop

        **returnGeoValues : bool**

        This property holds a value indicating if geomagnetic values should be
        returned.

        Set to true to return geomagnetic flux density. Set to false (the
        default) to return raw magnetic flux density.

        The property must be set before calling **start** ().

        **Access functions:**

        bool **returnGeoValues** () const
        void **setReturnGeoValues** (bool
        **returnGeoValues** )

        **Notifier signal:**

        void **returnGeoValuesChanged** (bool **returnGeoValues** )

        **Member Function Documentation**
        """
        ...

    def returnGeoValues(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#returnGeoValues-prop

        **returnGeoValues : bool**

        This property holds a value indicating if geomagnetic values should be
        returned.

        Set to true to return geomagnetic flux density. Set to false (the
        default) to return raw magnetic flux density.

        The property must be set before calling **start** ().

        **Access functions:**

        bool **returnGeoValues** () const
        void **setReturnGeoValues** (bool
        **returnGeoValues** )

        **Notifier signal:**

        void **returnGeoValuesChanged** (bool **returnGeoValues** )

        **Member Function Documentation**
        """
        ...

    def reading(self) -> QMagnetometerReading:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#reading

        **QMagnetometerReading *QMagnetometer::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...

    @property
    def returnGeoValuesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QPixmapCache(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpixmapcache.html

    **Detailed Description**

    This class is a tool for optimized drawing with **QPixmap** . You can use it
    to store temporary pixmaps that are expensive to generate without using more
    storage space than **cacheLimit** (). Use **insert** () to insert pixmaps,
    **find** () to find them, and **clear** () to empty the cache.

    QPixmapCache contains no member data, only static functions to access the
    global pixmap cache. It creates an internal **QCache**  object for caching
    the pixmaps.

    The cache associates a pixmap with a user-provided string as a key, or with
    a **QPixmapCache::Key**  that the cache generates. Using
    **QPixmapCache::Key**  for keys is faster than using strings. The string API
    is very convenient for complex keys but the **QPixmapCache::Key**  API will
    be very efficient and convenient for a one-to-one object-to-pixmap mapping -
    in this case, you can store the keys as members of an object.

    If two pixmaps are inserted into the cache using equal keys then the last
    pixmap will replace the first pixmap in the cache. This follows the behavior
    of the **QHash**  and **QCache**  classes.

    The cache becomes full when the total size of all pixmaps in the cache
    exceeds **cacheLimit** (). The initial cache limit is 10240 KB (10 MB); you
    can change this by calling **setCacheLimit** () with the required value. A
    pixmap takes roughly ( **width** * **height** * **depth** )/8 bytes of
    memory.

    The **Qt Quarterly** article **Optimizing with QPixmapCache**  explains how
    to use QPixmapCache to speed up applications by caching the results of
    painting.

    **Note:** QPixmapCache is only usable from the application's main thread.
    Access from other threads will be ignored and return failure.

    **See also** **QCache**  and **QPixmap** .
    """

    class Key(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, other: "QPixmapCache.Key") -> None:
            ...

        def isValid(self) -> bool:
            ...

        def swap(self, other: "QPixmapCache.Key") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QPixmapCache") -> None:
        ...

    @staticmethod
    def setCacheLimit(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#setCacheLimit

        **[static] void QPixmapCache::setCacheLimit(int n )**

        Sets the cache limit to **n** kilobytes.

        The default setting is 10240 KB.

        **See also** **cacheLimit** ().
        """
        ...

    @staticmethod
    def replace(key: "QPixmapCache.Key", pixmap: QPixmap) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#replace

        **[static] bool QPixmapCache::replace(const QPixmapCache::Key & key ,
        const QPixmap & pixmap )**

        Replaces the pixmap associated with the given **key** with the
        **pixmap** specified. Returns `true` if the **pixmap** has been
        correctly inserted into the cache; otherwise returns `false`.

        **See also** **setCacheLimit** () and **insert** ().
        """
        ...

    @typing.overload
    @staticmethod
    def remove(key: str) -> None:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#remove

        **[static] void QPixmapCache::remove(const QString & key )**

        Removes the pixmap associated with **key** from the cache.
        """
        ...

    @typing.overload
    @staticmethod
    def remove(key: "QPixmapCache.Key") -> None:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#remove-1

        **[static] void QPixmapCache::remove(const QPixmapCache::Key & key )**

        Removes the pixmap associated with **key** from the cache and releases
        the key for a future insertion.
        """
        ...

    @typing.overload
    @staticmethod
    def insert(key: str, a1: QPixmap) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#insert

        **[static] bool QPixmapCache::insert(const QString & key , const QPixmap
        & pixmap )**

        Inserts a copy of the pixmap **pixmap** associated with the **key** into
        the cache.

        All pixmaps inserted by the Qt library have a key starting with "$qt",
        so your own pixmap keys should never begin "$qt".

        When a pixmap is inserted and the cache is about to exceed its limit, it
        removes pixmaps until there is enough room for the pixmap to be
        inserted.

        The oldest pixmaps (least recently accessed in the cache) are deleted
        when more space is needed.

        The function returns `true` if the object was inserted into the cache;
        otherwise it returns `false`.

        **See also** **setCacheLimit** ().
        """
        ...

    @typing.overload
    @staticmethod
    def insert(pixmap: QPixmap) -> "QPixmapCache.Key":
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#insert-1

        **[static] QPixmapCache::Key QPixmapCache::insert(const QPixmap & pixmap
        )**

        Inserts a copy of the given **pixmap** into the cache and returns a key
        that can be used to retrieve it.

        When a pixmap is inserted and the cache is about to exceed its limit, it
        removes pixmaps until there is enough room for the pixmap to be
        inserted.

        The oldest pixmaps (least recently accessed in the cache) are deleted
        when more space is needed.

        **See also** **setCacheLimit** () and **replace** ().
        """
        ...

    @typing.overload
    @staticmethod
    def find(key: str) -> QPixmap:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#find

        **[static] bool QPixmapCache::find(const QString & key , QPixmap *
        pixmap )**

        Looks for a cached pixmap associated with the given **key** in the
        cache. If the pixmap is found, the function sets **pixmap** to that
        pixmap and returns `true`; otherwise it leaves **pixmap** alone and
        returns `false`.

        Example:

        **QPixmap**  pm;
            if (!**QPixmapCache** ::find("my_big_image", &pm))
        {
                pm.load("bigimage.png");
                **QPixmapCache**
        ::insert("my_big_image", pm);
            }
            painter->drawPixmap(0, 0, pm);
        """
        ...

    @typing.overload
    @staticmethod
    def find(key: "QPixmapCache.Key") -> QPixmap:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#find-1

        **[static] bool QPixmapCache::find(const QPixmapCache::Key & key ,
        QPixmap * pixmap )**

        Looks for a cached pixmap associated with the given **key** in the
        cache. If the pixmap is found, the function sets **pixmap** to that
        pixmap and returns `true`; otherwise it leaves **pixmap** alone and
        returns `false`. If the pixmap is not found, it means that the **key**
        is no longer valid, so it will be released for the next insertion.
        """
        ...

    @staticmethod
    def clear() -> None:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#clear

        **[static] void QPixmapCache::clear()**

        Removes all pixmaps from the cache.
        """
        ...

    @staticmethod
    def cacheLimit() -> int:
        """
        https://doc.qt.io/qt-6/qpixmapcache.html#cacheLimit

        **[static] int QPixmapCache::cacheLimit()**

        Returns the cache limit (in kilobytes).

        The default cache limit is 10240 KB.

        **See also** **setCacheLimit** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGTextureMaterial(QSGOpaqueTextureMaterial):
    """
    https://doc.qt.io/qt-6/qsgtexturematerial.html

    **Detailed Description**

    **Warning:** This utility class is only functional when running with the
    default backend of the Qt Quick scenegraph.

    The textured material will fill every pixel in a geometry with the supplied
    texture.

    The geometry to be rendered with a texture material requires vertices in
    attribute location 0 and texture coordinates in attribute location 1. The
    texture coordinate is a 2-dimensional floating-point tuple. The
    **QSGGeometry::defaultAttributes_TexturedPoint2D**  returns an attribute set
    compatible with this material.

    The texture to be rendered can be set using **setTexture** (). How the
    texture should be rendered can be specified using **setMipmapFiltering** (),
    **setFiltering** (), **setHorizontalWrapMode** () and
    **setVerticalWrapMode** (). The rendering state is set on the texture
    instance just before it is bound.

    The textured material respects the current matrix and the alpha channel of
    the texture. It will also respect the accumulated opacity in the scenegraph.

    A texture material must have a texture set before it is used as a material
    in the scene graph.
    """

    def __init__(self) -> None:
        ...

    def createShader(
        self, renderMode: QSGRendererInterface.RenderMode
    ) -> QSGMaterialShader:
        ...

    def type(self) -> QSGMaterialType:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QTextItem(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextitem.html

    **Detailed Description**

    When you reimplement your own paint engine, you must reimplement
    **QPaintEngine::drawTextItem** (), a function that takes a QTextItem as one
    of its arguments.
    """

    class RenderFlag(enum.Flag):
        RightToLeft: QTextItem = ...
        Overline: QTextItem = ...
        Underline: QTextItem = ...
        StrikeOut: QTextItem = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QTextItem") -> None:
        ...

    def font(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qtextitem.html#font

        **QFont QTextItem::font() const**

        Returns the font that should be used to draw the text.
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextitem.html#text

        **QString QTextItem::text() const**

        Returns the text that should be drawn.
        """
        ...

    def renderFlags(self) -> "QTextItem.RenderFlag":
        """
        https://doc.qt.io/qt-6/qtextitem.html#renderFlags

        **QTextItem::RenderFlags QTextItem::renderFlags() const**

        Returns the render flags used.
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextitem.html#width

        **qreal QTextItem::width() const**

        Specifies the total width of the text to be drawn.
        """
        ...

    def ascent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextitem.html#ascent

        **qreal QTextItem::ascent() const**

        Corresponds to the **ascent**  of the piece of text that is drawn.
        """
        ...

    def descent(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextitem.html#descent

        **qreal QTextItem::descent() const**

        Corresponds to the **descent**  of the piece of text that is drawn.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QDialogButtonBox(QWidget):
    """
    https://doc.qt.io/qt-6/qdialogbuttonbox.html

    **Detailed Description**

    Dialogs and message boxes typically present buttons in a layout that
    conforms to the interface guidelines for that platform. Invariably,
    different platforms have different layouts for their dialogs.
    QDialogButtonBox allows a developer to add buttons to it and will
    automatically use the appropriate layout for the user's desktop environment.

    Most buttons for a dialog follow certain roles. Such roles include:

    * Accepting or rejecting the dialog.
      * Asking for help.
      * Performing
    actions on the dialog itself (such as resetting fields or applying changes).

    There can also be alternate ways of dismissing the dialog which may cause
    destructive results.

    Most dialogs have buttons that can almost be considered standard (e.g.
    **OK** and **Cancel** buttons). It is sometimes convenient to create these
    buttons in a standard way.

    There are a couple ways of using QDialogButtonBox. One ways is to create the
    buttons (or button texts) yourself and add them to the button box,
    specifying their role.

    findButton = new **QPushButton** (tr("&Find"));
    findButton->setDefault(true);

            moreButton = new **QPushButton**
    (tr("&More"));
            moreButton->setCheckable(true);
    moreButton->setAutoDefault(false);

    Alternatively, QDialogButtonBox provides several standard buttons (e.g. OK,
    Cancel, Save) that you can use. They exist as flags so you can OR them
    together in the constructor.

    buttonBox = new **QDialogButtonBox** (**QDialogButtonBox** ::Ok
    | **QDialogButtonBox** ::Cancel);

            connect(buttonBox,
    &**QDialogButtonBox** ::accepted, this, &**QDialog** ::accept);
    connect(buttonBox, &**QDialogButtonBox** ::rejected, this, &**QDialog**
    ::reject);

    You can mix and match normal buttons and standard buttons.

    Currently the buttons are laid out in the following way if the button box is
    horizontal:

    ![GnomeLayout Horizontal](images/buttonbox-gnomelayout-horizontal.png)Button
    box laid out in horizontal **GnomeLayout**
    ![KdeLayout
    Horizontal](images/buttonbox-kdelayout-horizontal.png)Button box laid out in
    horizontal **KdeLayout**
    ![MacLayout Horizontal](images/buttonbox-
    maclayout-horizontal.png)Button box laid out in horizontal **MacLayout**
    ![WinLayout Horizontal](images/buttonbox-winlayout-horizontal.png)Button box
    laid out in horizontal **WinLayout**

    The buttons are laid out the following way if the button box is vertical:

    **GnomeLayout** **KdeLayout** **MacLayout** **WinLayout**
    ![GnomeLayout
    Vertical](images/buttonbox-gnomelayout-vertical.png)![KdeLayout
    Vertical](images/buttonbox-kdelayout-vertical.png)![MacLayout
    Vertical](images/buttonbox-maclayout-vertical.png)![WinLayout
    Vertical](images/buttonbox-winlayout-vertical.png)

    Additionally, button boxes that contain only buttons with **ActionRole**  or
    **HelpRole**  can be considered modeless and have an alternate look on
    macOS:

    modeless horizontal **MacLayout** ![Screenshot of modeless horizontal
    MacLayout](images/buttonbox-mac-modeless-horizontal.png)
    modeless vertical
    **MacLayout** ![Screenshot of modeless vertical MacLayout](images/buttonbox-
    mac-modeless-vertical.png)

    When a button is clicked in the button box, the **clicked** () signal is
    emitted for the actual button is that is pressed. For convenience, if the
    button has an **AcceptRole** , **RejectRole** , or **HelpRole** , the
    **accepted** (), **rejected** (), or **helpRequested** () signals are
    emitted respectively.

    If you want a specific button to be default you need to call
    **QPushButton::setDefault** () on it yourself. However, if there is no
    default button set and to preserve which button is the default button across
    platforms when using the **QPushButton::autoDefault**  property, the first
    push button with the accept role is made the default button when the
    QDialogButtonBox is shown,

    **See also** **QMessageBox** , **QPushButton** , and **QDialog** .
    """

    class StandardButton(enum.Flag):
        NoButton: QDialogButtonBox = ...
        Ok: QDialogButtonBox = ...
        Save: QDialogButtonBox = ...
        SaveAll: QDialogButtonBox = ...
        Open: QDialogButtonBox = ...
        Yes: QDialogButtonBox = ...
        YesToAll: QDialogButtonBox = ...
        No: QDialogButtonBox = ...
        NoToAll: QDialogButtonBox = ...
        Abort: QDialogButtonBox = ...
        Retry: QDialogButtonBox = ...
        Ignore: QDialogButtonBox = ...
        Close: QDialogButtonBox = ...
        Cancel: QDialogButtonBox = ...
        Discard: QDialogButtonBox = ...
        Help: QDialogButtonBox = ...
        Apply: QDialogButtonBox = ...
        Reset: QDialogButtonBox = ...
        RestoreDefaults: QDialogButtonBox = ...

    class ButtonRole(enum.Enum):
        InvalidRole: QDialogButtonBox = ...
        AcceptRole: QDialogButtonBox = ...
        RejectRole: QDialogButtonBox = ...
        DestructiveRole: QDialogButtonBox = ...
        ActionRole: QDialogButtonBox = ...
        HelpRole: QDialogButtonBox = ...
        YesRole: QDialogButtonBox = ...
        NoRole: QDialogButtonBox = ...
        ResetRole: QDialogButtonBox = ...
        ApplyRole: QDialogButtonBox = ...

    class ButtonLayout(enum.Enum):
        WinLayout: QDialogButtonBox = ...
        MacLayout: QDialogButtonBox = ...
        KdeLayout: QDialogButtonBox = ...
        GnomeLayout: QDialogButtonBox = ...
        AndroidLayout: QDialogButtonBox = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#QDialogButtonBox

        **QDialogButtonBox::QDialogButtonBox(QWidget * parent = nullptr)**

        Constructs an empty, horizontal button box with the given **parent**.

        **See also** **orientation**  and **addButton** ().
        """
        ...

    @typing.overload
    def __init__(
        self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#QDialogButtonBox-1

        **QDialogButtonBox::QDialogButtonBox(Qt::Orientation orientation ,
        QWidget * parent = nullptr)**

        Constructs an empty button box with the given **orientation** and
        **parent**.

        **See also** **orientation**  and **addButton** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        buttons: "QDialogButtonBox.StandardButton",
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#QDialogButtonBox-2

        **[since 5.2]
        QDialogButtonBox::QDialogButtonBox(QDialogButtonBox::StandardButtons
        buttons , QWidget * parent = nullptr)**

        Constructs a horizontal button box with the given **parent** ,
        containing the standard buttons specified by **buttons**.

        This function was introduced in Qt 5.2.

        **See also** **orientation**  and **addButton** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        buttons: "QDialogButtonBox.StandardButton",
        orientation: QtCore.Qt.Orientation,
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#QDialogButtonBox-3

        **QDialogButtonBox::QDialogButtonBox(QDialogButtonBox::StandardButtons
        buttons , Qt::Orientation orientation , QWidget * parent = nullptr)**

        Constructs a button box with the given **orientation** and **parent** ,
        containing the standard buttons specified by **buttons**.

        **See also** **orientation**  and **addButton** ().
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#event

        **[override virtual protected] bool QDialogButtonBox::event(QEvent *
        event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def changeEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#changeEvent

        **[override virtual protected] void QDialogButtonBox::changeEvent(QEvent
        * event )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def centerButtons(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#centerButtons-prop

        **centerButtons : bool**

        This property holds whether the buttons in the button box are centered

        By default, this property is `false`. This behavior is appropriate for
        most types of dialogs. A notable exception is message boxes on most
        platforms (e.g. Windows), where the button box is centered horizontally.

        **Access functions:**

        bool **centerButtons** () const
        void **setCenterButtons** (bool
        **center** )

        **See also** **QMessageBox** .
        """
        ...

    def setCenterButtons(self, center: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#centerButtons-prop

        **centerButtons : bool**

        This property holds whether the buttons in the button box are centered

        By default, this property is `false`. This behavior is appropriate for
        most types of dialogs. A notable exception is message boxes on most
        platforms (e.g. Windows), where the button box is centered horizontally.

        **Access functions:**

        bool **centerButtons** () const
        void **setCenterButtons** (bool
        **center** )

        **See also** **QMessageBox** .
        """
        ...

    def button(self, which: "QDialogButtonBox.StandardButton") -> QPushButton:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#button

        **QPushButton *QDialogButtonBox::button(QDialogButtonBox::StandardButton
        which ) const**

        Returns the **QPushButton**  corresponding to the standard button
        **which** , or `nullptr` if the standard button doesn't exist in this
        button box.

        **See also** **standardButton** (), **standardButtons** (), and
        **buttons** ().
        """
        ...

    def standardButton(
        self, button: QAbstractButton
    ) -> "QDialogButtonBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#standardButton

        **QDialogButtonBox::StandardButton
        QDialogButtonBox::standardButton(QAbstractButton * button ) const**

        Returns the standard button enum value corresponding to the given
        **button** , or **NoButton**  if the given **button** isn't a standard
        button.

        **See also** **button** (), **buttons** (), and **standardButtons** ().
        """
        ...

    def standardButtons(self) -> "QDialogButtonBox.StandardButton":
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#standardButtons-prop

        **standardButtons : StandardButtons**

        collection of standard buttons in the button box

        This property controls which standard buttons are used by the button
        box.

        **Access functions:**

        QDialogButtonBox::StandardButtons **standardButtons** () const
        void
        **setStandardButtons** (QDialogButtonBox::StandardButtons **buttons** )

        **See also** **addButton** ().

        **Member Function Documentation**
        """
        ...

    def setStandardButtons(self, buttons: "QDialogButtonBox.StandardButton") -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#standardButtons-prop

        **standardButtons : StandardButtons**

        collection of standard buttons in the button box

        This property controls which standard buttons are used by the button
        box.

        **Access functions:**

        QDialogButtonBox::StandardButtons **standardButtons** () const
        void
        **setStandardButtons** (QDialogButtonBox::StandardButtons **buttons** )

        **See also** **addButton** ().

        **Member Function Documentation**
        """
        ...

    def buttonRole(self, button: QAbstractButton) -> "QDialogButtonBox.ButtonRole":
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#buttonRole

        **QDialogButtonBox::ButtonRole
        QDialogButtonBox::buttonRole(QAbstractButton * button ) const**

        Returns the button role for the specified **button**. This function
        returns **InvalidRole**  if **button** is `nullptr` or has not been
        added to the button box.

        **See also** **buttons** () and **addButton** ().
        """
        ...

    def buttons(self) -> typing.List[QAbstractButton]:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#buttons

        **QList<QAbstractButton *> QDialogButtonBox::buttons() const**

        Returns a list of all the buttons that have been added to the button
        box.

        **See also** **buttonRole** (), **addButton** (), and **removeButton**
        ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#clear

        **void QDialogButtonBox::clear()**

        Clears the button box, deleting all buttons within it.

        **See also** **removeButton** () and **addButton** ().
        """
        ...

    def removeButton(self, button: QAbstractButton) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#removeButton

        **void QDialogButtonBox::removeButton(QAbstractButton * button )**

        Removes **button** from the button box without deleting it and sets its
        parent to zero.

        **See also** **clear** (), **buttons** (), and **addButton** ().
        """
        ...

    @typing.overload
    def addButton(
        self, button: QAbstractButton, role: "QDialogButtonBox.ButtonRole"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#addButton

        **void QDialogButtonBox::addButton(QAbstractButton * button ,
        QDialogButtonBox::ButtonRole role )**

        Adds the given **button** to the button box with the specified **role**.
        If the role is invalid, the button is not added.

        If the button has already been added, it is removed and added again with
        the new role.

        **Note:** The button box takes ownership of the button.

        **See also** **removeButton** () and **clear** ().
        """
        ...

    @typing.overload
    def addButton(self, text: str, role: "QDialogButtonBox.ButtonRole") -> QPushButton:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#addButton-1

        **QPushButton *QDialogButtonBox::addButton(const QString & text ,
        QDialogButtonBox::ButtonRole role )**

        Creates a push button with the given **text** , adds it to the button
        box for the specified **role** , and returns the corresponding push
        button. If **role** is invalid, no button is created, and zero is
        returned.

        **See also** **removeButton** () and **clear** ().
        """
        ...

    @typing.overload
    def addButton(self, button: "QDialogButtonBox.StandardButton") -> QPushButton:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#addButton-2

        **QPushButton
        *QDialogButtonBox::addButton(QDialogButtonBox::StandardButton button )**

        Adds a standard **button** to the button box if it is valid to do so,
        and returns a push button. If **button** is invalid, it is not added to
        the button box, and zero is returned.

        **See also** **removeButton** () and **clear** ().
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the button box

        By default, the orientation is horizontal (i.e. the buttons are laid out
        side by side). The possible orientations are **Qt::Horizontal**  and
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **orientation** )
        """
        ...

    def setOrientation(self, orientation: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the button box

        By default, the orientation is horizontal (i.e. the buttons are laid out
        side by side). The possible orientations are **Qt::Horizontal**  and
        **Qt::Vertical** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **orientation** )
        """
        ...

    @property
    def accepted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#accepted

        **[signal] void QDialogButtonBox::accepted()**

        This signal is emitted when a button inside the button box is clicked,
        as long as it was defined with the **AcceptRole**  or **YesRole** .

        **See also** **rejected** (), **clicked** (), and **helpRequested** ().
        """
        ...

    @property
    def clicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#clicked

        **[signal] void QDialogButtonBox::clicked(QAbstractButton * button )**

        This signal is emitted when a button inside the button box is clicked.
        The specific button that was pressed is specified by **button**.

        **See also** **accepted** (), **rejected** (), and **helpRequested** ().
        """
        ...

    @property
    def helpRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#helpRequested

        **[signal] void QDialogButtonBox::helpRequested()**

        This signal is emitted when a button inside the button box is clicked,
        as long as it was defined with the **HelpRole** .

        **See also** **accepted** (), **rejected** (), and **clicked** ().
        """
        ...

    @property
    def rejected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdialogbuttonbox.html#rejected

        **[signal] void QDialogButtonBox::rejected()**

        This signal is emitted when a button inside the button box is clicked,
        as long as it was defined with the **RejectRole**  or **NoRole** .

        **See also** **accepted** (), **helpRequested** (), and **clicked** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsRotation(QGraphicsTransform):
    """
    https://doc.qt.io/qt-6/qgraphicsrotation.html

    **Detailed Description**

    You can provide the desired axis by assigning a **QVector3D**  to the axis
    property or by passing a member if **Qt::Axis**  to the **setAxis**
    convenience function. By default the axis is (0, 0, 1) i.e., rotation around
    the Z axis.

    The angle property, which is provided by QGraphicsRotation, now describes
    the number of degrees to rotate around this axis.

    QGraphicsRotation provides certain parameters to help control how the
    rotation should be applied.

    The origin is the point that the item is rotated around (i.e., it stays
    fixed relative to the parent as the rest of the item is rotated). By default
    the origin is **QPointF** (0, 0).

    The angle property provides the number of degrees to rotate the item
    clockwise around the origin. This value also be negative, indicating a
    counter-clockwise rotation. For animation purposes it may also be useful to
    provide rotation angles exceeding (-360, 360) degrees, for instance to
    animate how an item rotates several times.

    Note: the final rotation is the combined effect of a rotation in 3D space
    followed by a projection back to 2D. If several rotations are performed in
    succession, they will not behave as expected unless they were all around the
    Z axis.

    **See also** **QGraphicsTransform** , **QGraphicsItem::setRotation** (), and
    **QTransform::rotate** ().
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#QGraphicsRotation

        **QGraphicsRotation::QGraphicsRotation(QObject * parent = nullptr)**

        Constructs a new QGraphicsRotation with the given **parent**.
        """
        ...

    def applyTo(self, matrix: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#applyTo

        **[override virtual] void QGraphicsRotation::applyTo(QMatrix4x4 * matrix
        ) const**

        Reimplements: **QGraphicsTransform::applyTo(QMatrix4x4 *matrix) const**
        .
        """
        ...

    @typing.overload
    def setAxis(self, axis: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#setAxis-1

        **void QGraphicsRotation::setAxis(Qt::Axis axis )**

        Convenience function to set the axis to **axis**.

        Note: the **Qt::YAxis**  rotation for **QTransform**  is inverted from
        the correct mathematical rotation in 3D space. The **QGraphicsRotation**
        class implements a correct mathematical rotation. The following two
        sequences of code will perform the same transformation:

        **QTransform**  t;
            t.rotate(45, Qt::YAxis);
        **QGraphicsRotation**  r;
            r.setAxis(Qt::YAxis);
            r.setAngle(-45);

        **Note:** Setter function for property **axis** .
        """
        ...

    @typing.overload
    def setAxis(self, axis: QtCore.Qt.Axis) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#axis-prop

        **axis : QVector3D**

        This property holds a rotation axis, specified by a vector in 3D space.

        This can be any axis in 3D space. By default the axis is (0, 0, 1),
        which is aligned with the Z axis. If you provide another axis,
        **QGraphicsRotation**  will provide a transformation that rotates around
        this axis. For example, if you would like to rotate an item around its X
        axis, you could pass (1, 0, 0) as the axis.

        **Access functions:**

        QVector3D **axis** () const
        void **setAxis** (const QVector3D &
        **axis** )
        void ****setAxis** ** (Qt::Axis **axis** )

        **Notifier signal:**

        void ****axisChanged** ** ()

        **See also** **QTransform**  and **QGraphicsRotation::angle** .
        """
        ...

    def axis(self) -> QtGui.QVector3D:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#axis-prop

        **axis : QVector3D**

        This property holds a rotation axis, specified by a vector in 3D space.

        This can be any axis in 3D space. By default the axis is (0, 0, 1),
        which is aligned with the Z axis. If you provide another axis,
        **QGraphicsRotation**  will provide a transformation that rotates around
        this axis. For example, if you would like to rotate an item around its X
        axis, you could pass (1, 0, 0) as the axis.

        **Access functions:**

        QVector3D **axis** () const
        void **setAxis** (const QVector3D &
        **axis** )
        void ****setAxis** ** (Qt::Axis **axis** )

        **Notifier signal:**

        void ****axisChanged** ** ()

        **See also** **QTransform**  and **QGraphicsRotation::angle** .
        """
        ...

    def setAngle(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#angle-prop

        **angle : qreal**

        This property holds the angle for clockwise rotation, in degrees.

        The angle can be any real number; the default value is 0.0. A value of
        180 will rotate 180 degrees, clockwise. If you provide a negative
        number, the item will be rotated counter-clockwise. Normally the
        rotation angle will be in the range (-360, 360), but you can also
        provide numbers outside of this range (e.g., a angle of 370 degrees
        gives the same result as 10 degrees). Setting the angle to NaN results
        in no rotation.

        **Access functions:**

        qreal **angle** () const
        void **setAngle** (qreal)

        **Notifier signal:**

        void ****angleChanged** ** ()

        **See also** **origin** .
        """
        ...

    def angle(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#angle-prop

        **angle : qreal**

        This property holds the angle for clockwise rotation, in degrees.

        The angle can be any real number; the default value is 0.0. A value of
        180 will rotate 180 degrees, clockwise. If you provide a negative
        number, the item will be rotated counter-clockwise. Normally the
        rotation angle will be in the range (-360, 360), but you can also
        provide numbers outside of this range (e.g., a angle of 370 degrees
        gives the same result as 10 degrees). Setting the angle to NaN results
        in no rotation.

        **Access functions:**

        qreal **angle** () const
        void **setAngle** (qreal)

        **Notifier signal:**

        void ****angleChanged** ** ()

        **See also** **origin** .
        """
        ...

    def setOrigin(self, point: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#origin-prop

        **origin : QVector3D**

        This property holds the origin of the rotation in 3D space.

        All rotations will be done relative to this point (i.e., this point will
        stay fixed, relative to the parent, when the item is rotated).

        **Access functions:**

        QVector3D **origin** () const
        void **setOrigin** (const QVector3D &
        **point** )

        **Notifier signal:**

        void ****originChanged** ** ()

        **See also** **angle** .

        **Member Function Documentation**
        """
        ...

    def origin(self) -> QtGui.QVector3D:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#origin-prop

        **origin : QVector3D**

        This property holds the origin of the rotation in 3D space.

        All rotations will be done relative to this point (i.e., this point will
        stay fixed, relative to the parent, when the item is rotated).

        **Access functions:**

        QVector3D **origin** () const
        void **setOrigin** (const QVector3D &
        **point** )

        **Notifier signal:**

        void ****originChanged** ** ()

        **See also** **angle** .

        **Member Function Documentation**
        """
        ...

    @property
    def angleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#angleChanged

        **[signal] void QGraphicsRotation::angleChanged()**

        This signal is emitted whenever the angle has changed.

        **Note:** Notifier signal for property **angle** .

        **See also** **QGraphicsRotation::angle** .
        """
        ...

    @property
    def axisChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#axisChanged

        **[signal] void QGraphicsRotation::axisChanged()**

        This signal is emitted whenever the axis of the object changes.

        **Note:** Notifier signal for property **axis** .

        **See also** **QGraphicsRotation::axis** .
        """
        ...

    @property
    def originChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsrotation.html#originChanged

        **[signal] void QGraphicsRotation::originChanged()**

        This signal is emitted whenever the origin has changed.

        **Note:** Notifier signal for property **origin** .

        **See also** **QGraphicsRotation::origin** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QDesignerActionEditorInterface import (
    QDesignerActionEditorInterface as QDesignerActionEditorInterface,
)
from ._QAbstractFormBuilder import QAbstractFormBuilder as QAbstractFormBuilder
from ._QDesignerFormEditorInterface import (
    QDesignerFormEditorInterface as QDesignerFormEditorInterface,
)
from ._QDesignerFormWindowInterface import (
    QDesignerFormWindowInterface as QDesignerFormWindowInterface,
)
from ._QDesignerFormWindowCursorInterface import (
    QDesignerFormWindowCursorInterface as QDesignerFormWindowCursorInterface,
)
from ._QDesignerFormWindowManagerInterface import (
    QDesignerFormWindowManagerInterface as QDesignerFormWindowManagerInterface,
)
from ._QDesignerObjectInspectorInterface import (
    QDesignerObjectInspectorInterface as QDesignerObjectInspectorInterface,
)
from ._QDesignerPropertyEditorInterface import (
    QDesignerPropertyEditorInterface as QDesignerPropertyEditorInterface,
)
from ._QDesignerWidgetBoxInterface import (
    QDesignerWidgetBoxInterface as QDesignerWidgetBoxInterface,
)
from ._QDesignerContainerExtension import (
    QDesignerContainerExtension as QDesignerContainerExtension,
)
from ._QDesignerCustomWidgetInterface import (
    QDesignerCustomWidgetInterface as QDesignerCustomWidgetInterface,
)
from ._QDesignerCustomWidgetCollectionInterface import (
    QDesignerCustomWidgetCollectionInterface as QDesignerCustomWidgetCollectionInterface,
)
from ._QAbstractExtensionFactory import (
    QAbstractExtensionFactory as QAbstractExtensionFactory,
)
from ._QExtensionFactory import QExtensionFactory as QExtensionFactory
from ._QAbstractExtensionManager import (
    QAbstractExtensionManager as QAbstractExtensionManager,
)
from ._QFormBuilder import QFormBuilder as QFormBuilder
from ._QDesignerMemberSheetExtension import (
    QDesignerMemberSheetExtension as QDesignerMemberSheetExtension,
)
from ._QDesignerPropertySheetExtension import (
    QDesignerPropertySheetExtension as QDesignerPropertySheetExtension,
)
from ._QExtensionManager import QExtensionManager as QExtensionManager
from ._QDesignerTaskMenuExtension import (
    QDesignerTaskMenuExtension as QDesignerTaskMenuExtension,
)
from ._QPyDesignerContainerExtension import (
    QPyDesignerContainerExtension as QPyDesignerContainerExtension,
)
from ._QPyDesignerCustomWidgetCollectionPlugin import (
    QPyDesignerCustomWidgetCollectionPlugin as QPyDesignerCustomWidgetCollectionPlugin,
)
from ._QPyDesignerCustomWidgetPlugin import (
    QPyDesignerCustomWidgetPlugin as QPyDesignerCustomWidgetPlugin,
)
from ._QPyDesignerMemberSheetExtension import (
    QPyDesignerMemberSheetExtension as QPyDesignerMemberSheetExtension,
)
from ._QPyDesignerPropertySheetExtension import (
    QPyDesignerPropertySheetExtension as QPyDesignerPropertySheetExtension,
)
from ._QPyDesignerTaskMenuExtension import (
    QPyDesignerTaskMenuExtension as QPyDesignerTaskMenuExtension,
)
